==> org.eclipse.scout.sdk.ui.source_3.7.2.201202140505.jar: org/eclipse/scout/sdk/ui/internal/view/outline/pages/project/server/service/common/CommonServicesNodePage.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.server.service.common;

import org.eclipse.scout.sdk.Texts;
import org.eclipse.scout.sdk.ui.ScoutSdkUi;
import org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.server.service.common.bookmark.BookmarkStorageServiceTablePage;
import org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.server.service.common.calendar.CalendarServiceTablePage;
import org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.server.service.common.smtp.SmtpServiceTablePage;
import org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.server.service.common.sql.SqlServiceTablePage;
import org.eclipse.scout.sdk.ui.view.outline.pages.AbstractPage;
import org.eclipse.scout.sdk.ui.view.outline.pages.IPage;
import org.eclipse.scout.sdk.ui.view.outline.pages.IScoutPageConstants;
import org.eclipse.scout.sdk.workspace.IScoutBundle;

public class CommonServicesNodePage extends AbstractPage {

  public CommonServicesNodePage(IPage parent) {
    setParent(parent);
    setName(Texts.get("ServerServicesCommonNodePage"));
  }

  @Override
  public String getPageId() {
    return IScoutPageConstants.COMMON_SERVICES_NODE_PAGE;
  }

  @Override
  public boolean isFolder() {
    return true;
  }

  /**
   * server bundle
   */
  @Override
  public IScoutBundle getScoutResource() {
    return (IScoutBundle) super.getScoutResource();
  }

  @Override
  public void loadChildrenImpl() {
    try {
      new SqlServiceTablePage(this);
    }
    catch (Exception e) {
      ScoutSdkUi.logError("could not create 'SqlServiceTablePage'.", e);
    }
    try {
      new BookmarkStorageServiceTablePage(this);
    }
    catch (Exception e) {
      ScoutSdkUi.logError("could not create 'BookmarkStorageServiceTablePage'.", e);
    }
    try {
      new CalendarServiceTablePage(this);
    }
    catch (Exception e) {
      ScoutSdkUi.logError("could not create 'CalendarServiceTablePage'.", e);
    }
    try {
      new SmtpServiceTablePage(this);
    }
    catch (Exception e) {
      ScoutSdkUi.logError("could not create 'SmtpServiceTablePage'.", e);
    }
  }

  @Override
  public boolean isInitiallyLoaded() {
    return true;
  }

}

==> org.eclipse.scout.sdk.ui.source_3.8.0.201206130843.jar: org/eclipse/scout/sdk/ui/internal/view/outline/pages/project/server/service/common/CommonServicesNodePage.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.server.service.common;

import org.eclipse.scout.sdk.Texts;
import org.eclipse.scout.sdk.ui.internal.ScoutSdkUi;
import org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.server.service.common.bookmark.BookmarkStorageServiceTablePage;
import org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.server.service.common.calendar.CalendarServiceTablePage;
import org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.server.service.common.smtp.SmtpServiceTablePage;
import org.eclipse.scout.sdk.ui.internal.view.outline.pages.project.server.service.common.sql.SqlServiceTablePage;
import org.eclipse.scout.sdk.ui.view.outline.pages.AbstractPage;
import org.eclipse.scout.sdk.ui.view.outline.pages.IPage;
import org.eclipse.scout.sdk.ui.view.outline.pages.IScoutPageConstants;
import org.eclipse.scout.sdk.workspace.IScoutBundle;

public class CommonServicesNodePage extends AbstractPage {

  public CommonServicesNodePage(IPage parent) {
    setParent(parent);
    setImageDescriptor(ScoutSdkUi.getImageDescriptor(ScoutSdkUi.Services));
    setName(Texts.get("ServerServicesCommonNodePage"));
  }

  @Override
  public String getPageId() {
    return IScoutPageConstants.COMMON_SERVICES_NODE_PAGE;
  }

  @Override
  public boolean isFolder() {
    return true;
  }

  /**
   * server bundle
   */
  @Override
  public IScoutBundle getScoutResource() {
    return (IScoutBundle) super.getScoutResource();
  }

  @Override
  public void loadChildrenImpl() {
    try {
      new SqlServiceTablePage(this);
    }
    catch (Exception e) {
      ScoutSdkUi.logError("could not create 'SqlServiceTablePage'.", e);
    }
    try {
      new BookmarkStorageServiceTablePage(this);
    }
    catch (Exception e) {
      ScoutSdkUi.logError("could not create 'BookmarkStorageServiceTablePage'.", e);
    }
    try {
      new CalendarServiceTablePage(this);
    }
    catch (Exception e) {
      ScoutSdkUi.logError("could not create 'CalendarServiceTablePage'.", e);
    }
    try {
      new SmtpServiceTablePage(this);
    }
    catch (Exception e) {
      ScoutSdkUi.logError("could not create 'SmtpServiceTablePage'.", e);
    }
  }

  @Override
  public boolean isInitiallyLoaded() {
    return true;
  }

}
